@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "lineeditwithautocorrectiontest.h"
 #include <PimCommon/LineEditWithAutoCorrection>
-#include <PimCommonAutoCorrection/AutoCorrection>
 #include <QTest>
+#include <TextAutoCorrection/AutoCorrection>
 #include <qtestkeyboard.h>
 
 LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest() = default;
@@ -19,7 +19,7 @@ void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
     const QString originalWord = QStringLiteral("FOOFOO");
     const QString replaceWord = QStringLiteral("BLABLA");
     entries.insert(originalWord, replaceWord);
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
     settings->setAutocorrectEntries(entries);
     lineedit.autocorrection()->setAutoCorrectionSettings(settings);
     lineedit.show();
@@ -36,7 +36,7 @@ void LineEditWithAutocorrectionTest::shouldReplaceWordWhenExactText()
     const QString replaceWord = QStringLiteral("BLABLA");
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
     settings->setAutocorrectEntries(entries);
     settings->setEnabledAutoCorrection(true);
     settings->setAdvancedAutocorrect(true);
@@ -55,7 +55,7 @@ void LineEditWithAutocorrectionTest::shouldNotReplaceWordWhenInexactText()
     const QString replaceWord = QStringLiteral("BLABLA");
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
     settings->setAutocorrectEntries(entries);
     settings->setEnabledAutoCorrection(true);
     settings->setAdvancedAutocorrect(true);
@@ -72,7 +72,7 @@ void LineEditWithAutocorrectionTest::shouldNotAddTwoSpace()
 {
     PimCommon::LineEditWithAutoCorrection lineedit(nullptr, QStringLiteral("lineeditwithautocorrecttestrc"));
     const QString originalWord = QStringLiteral("FOOFOO ");
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
     settings->setSingleSpaces(true);
     settings->setEnabledAutoCorrection(true);
     lineedit.autocorrection()->setAutoCorrectionSettings(settings);
