@@ -1,11 +1,10 @@
 /*
- * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef SpellCheckLineEdit_H
-#define SpellCheckLineEdit_H
+#pragma once
 #include "pimcommon_export.h"
 #include <KPIMTextEdit/RichTextEditor>
 
@@ -48,4 +47,3 @@ Q_SIGNALS:
     void focusDown();
 };
 }
-#endif /* SpellCheckLineEdit_H */
