@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -40,7 +40,6 @@ private:
     void slotSave();
     void readConfig();
     void writeConfig();
-    CompletionConfigureDialogPrivate *const d;
+    std::unique_ptr<CompletionConfigureDialogPrivate> const d;
 };
 }
-
