@@ -6,9 +6,10 @@
 
 #include "collectionpage/attributes/collectionannotationsattribute.h"
 
-#include <AkonadiCore/attributefactory.h>
+#include <Akonadi/AttributeFactory>
 
-namespace {
+namespace
+{
 // Anonymous namespace; function is invisible outside this file.
 bool dummy()
 {
